import { Editor, Range } from '@tiptap/core';
import { PluginKey, EditorState, Plugin } from '@tiptap/pm/state';
import { EditorView } from '@tiptap/pm/view';
import { ResolvedPos } from '@tiptap/pm/model';

interface SuggestionOptions<I = any> {
    pluginKey?: PluginKey;
    editor: Editor;
    char?: string;
    allowSpaces?: boolean;
    allowedPrefixes?: string[] | null;
    startOfLine?: boolean;
    decorationTag?: string;
    decorationClass?: string;
    command?: (props: {
        editor: Editor;
        range: Range;
        props: I;
    }) => void;
    items?: (props: {
        query: string;
        editor: Editor;
    }) => I[] | Promise<I[]>;
    render?: () => {
        onBeforeStart?: (props: SuggestionProps<I>) => void;
        onStart?: (props: SuggestionProps<I>) => void;
        onBeforeUpdate?: (props: SuggestionProps<I>) => void;
        onUpdate?: (props: SuggestionProps<I>) => void;
        onExit?: (props: SuggestionProps<I>) => void;
        onKeyDown?: (props: SuggestionKeyDownProps) => boolean;
    };
    allow?: (props: {
        editor: Editor;
        state: EditorState;
        range: Range;
    }) => boolean;
}
interface SuggestionProps<I = any> {
    editor: Editor;
    range: Range;
    query: string;
    text: string;
    items: I[];
    command: (props: I) => void;
    decorationNode: Element | null;
    clientRect?: (() => DOMRect | null) | null;
}
interface SuggestionKeyDownProps {
    view: EditorView;
    event: KeyboardEvent;
    range: Range;
}
declare const SuggestionPluginKey: PluginKey<any>;
declare function Suggestion<I = any>({ pluginKey, editor, char, allowSpaces, allowedPrefixes, startOfLine, decorationTag, decorationClass, command, items, render, allow, }: SuggestionOptions<I>): Plugin<any>;

interface Trigger {
    char: string;
    allowSpaces: boolean;
    allowedPrefixes: string[] | null;
    startOfLine: boolean;
    $position: ResolvedPos;
}
declare type SuggestionMatch = {
    range: Range;
    query: string;
    text: string;
} | null;
declare function findSuggestionMatch(config: Trigger): SuggestionMatch;

export { Suggestion, SuggestionKeyDownProps, SuggestionMatch, SuggestionOptions, SuggestionPluginKey, SuggestionProps, Trigger, Suggestion as default, findSuggestionMatch };
